<p align="center">
  <a title="edaa-org.github.io/pyEDAA.IPXACT" href="https://edaa-org.github.io/pyEDAA.IPXACT"><img height="80px" src="doc/_static/logo.svg"/></a>
</p>

[![Sourcecode on GitHub](https://img.shields.io/badge/pyEDAA-IPXACT-29b6f6.svg?longCache=true&style=flat-square&logo=GitHub&labelColor=0277bd)](https://GitHub.com/edaa-org/pyEDAA.IPXACT)
[![Sourcecode License](https://img.shields.io/pypi/l/pyEDAA.IPXACT?longCache=true&style=flat-square&logo=Apache&label=code)](LICENSE.md)
[![Documentation](https://img.shields.io/website?longCache=true&style=flat-square&label=edaa-org.github.io%2FpyEDAA.IPXACT&logo=GitHub&logoColor=fff&up_color=blueviolet&up_message=Read%20now%20%E2%9E%9A&url=https%3A%2F%2Fedaa-org.github.io%2FpyEDAA.IPXACT%2Findex.html)](https://edaa-org.github.io/pyEDAA.IPXACT/)
[![Documentation License](https://img.shields.io/badge/doc-CC--BY%204.0-green?longCache=true&style=flat-square&logo=CreativeCommons&logoColor=fff)](LICENSE.md)  
[![PyPI](https://img.shields.io/pypi/v/pyEDAA.IPXACT?longCache=true&style=flat-square&logo=PyPI&logoColor=FBE072)](https://pypi.org/project/pyEDAA.IPXACT/)
![PyPI - Status](https://img.shields.io/pypi/status/pyEDAA.IPXACT?longCache=true&style=flat-square&logo=PyPI&logoColor=FBE072)
![PyPI - Python Version](https://img.shields.io/pypi/pyversions/pyEDAA.IPXACT?longCache=true&style=flat-square&logo=PyPI&logoColor=FBE072)  
[![GitHub Workflow - Build and Test Status](https://img.shields.io/github/actions/workflow/status/edaa-org/pyEDAA.IPXACT/Pipeline.yml?longCache=true&style=flat-square&label=Build%20and%20Test&logo=GitHub%20Actions&logoColor=FFFFFF)](https://GitHub.com/edaa-org/pyEDAA.IPXACT/actions/workflows/Pipeline.yml)
[![Libraries.io status for latest release](https://img.shields.io/librariesio/release/pypi/pyEDAA.IPXACT?longCache=true&style=flat-square&logo=Libraries.io&logoColor=fff)](https://libraries.io/github/edaa-org/pyEDAA.IPXACT)
[![Codacy - Quality](https://img.shields.io/codacy/grade/c924eeffd4cc49ed9ebbbe3a89b6fa76?longCache=true&style=flat-square&logo=Codacy)](https://app.codacy.com/gh/edaa-org/pyEDAA.IPXACT)
[![Codacy - Coverage](https://img.shields.io/codacy/coverage/c924eeffd4cc49ed9ebbbe3a89b6fa76?longCache=true&style=flat-square&logo=Codacy)](https://app.codacy.com/gh/edaa-org/pyEDAA.IPXACT)
[![Codecov - Branch Coverage](https://img.shields.io/codecov/c/github/edaa-org/pyEDAA.IPXACT?longCache=true&style=flat-square&logo=Codecov)](https://codecov.io/gh/edaa-org/pyEDAA.IPXACT)

<!--
[![Dependent repos (via libraries.io)](https://img.shields.io/librariesio/dependent-repos/pypi/pyEDAA.IPXACT?longCache=true&style=flat-square&logo=GitHub)](https://GitHub.com/edaa-org/pyEDAA.IPXACT/network/dependents)
[![Requires.io](https://img.shields.io/requires/github/edaa-org/pyEDAA.IPXACT?longCache=true&style=flat-square)](https://requires.io/github/EDAA-ORG/pyEDAA.IPXACT/requirements/?branch=main)
[![Libraries.io SourceRank](https://img.shields.io/librariesio/sourcerank/pypi/pyEDAA.IPXACT?longCache=true&style=flat-square)](https://libraries.io/github/edaa-org/pyEDAA.IPXACT/sourcerank)
-->

An IP-XACT Document Object Model (DOM) for [IEEE 1685-2022][IEEE-1685-2022] written in Python.

# Features

* Read IP-XACT files
  * Validate IP-XACT XML files with matching XML schema definition as provided by [Accellera - IP-XACT][IPXACT]
  * Read components
    * Extract filesets and files
* Generate IP-XACT files for
  * IP-XACT catalogs


# IP-XACT Resources

* Standards:
  * [IEEE 1685-2009][IEEE-1685-2009]
  * [IEEE 1685-2014][IEEE-1685-2014]
  * [IEEE 1685-2022][IEEE-1685-2022]
* Schema files:
  * [IPXACT-Schema](https://github.com/edaa-org/IPXACT-Schema) at GitHub
  * [IP-XACT][IPXACT] at [Accellera][Accellera]


# Contributors

* [Patrick Lehmann](https://github.com/Paebbels) (Maintainer)


# License

This Python package (source code) is licensed under [Apache License 2.0](LICENSE.md).  
The accompanying documentation is licensed under [Creative Commons - Attribution 4.0 (CC-BY 4.0)](doc/Doc-License.rst).

-------------------------
SPDX-License-Identifier: Apache-2.0


[IEEE-1685-2009]: https://standards.ieee.org/findstds/standard/1685-2009.html
[IEEE-1685-2014]: https://standards.ieee.org/findstds/standard/1685-2014.html
[IEEE-1685-2022]: https://standards.ieee.org/findstds/standard/1685-2022.html
[IPXACT]:         http://accellera.org/downloads/standards/ip-xact
[Accellera]:      http://accellera.org
